pub enum SystemMetricName {
MonitorUp,
HeartbeatUp,
MonitorSslDaysLeft,
MonitorDomainDaysLeft,
}Variants
MonitorUp
Base availability metric monitor.up
Indicates the availability of the monitor at the time of measurement (1 - was available, 0 - was not).
HeartbeatUp
Base availability metric heartbeat.up
Indicates the availability of the heartbeat (0 - was available, other - was not).
MonitorSslDaysLeft
Expiration metric monitor.ssl.days_left
Indicates how many days remain until the certificate expires.
MonitorDomainDaysLeft
Expiration metric monitor.domain.days_left
Indicates how many days remain until the domain name expires.