pub struct SystemMetric {
pub timestamp: OffsetDateTime,
pub target_id: i64,
pub target: Target,
pub name: SystemMetricName,
pub value: f32,
pub error: MetricError,
}Expand description
Represents a single metric event produced by a target at a concrete point in time.
Fields
timestamp: OffsetDateTimeUnix timestamp when the metric was created.
target_id: i64Unique identifier of the target that produced this metric.
target: TargetName of the target that produced this metric.
name: SystemMetricNameThe name of metric being reported.
value: f32Numeric value of the metric.
error: MetricErrorType of error associated with this metric.