PingConfig

Struct PingConfig 

pub struct PingConfig {
    pub check_frequency: i64,
    pub confirmation_period: i64,
    pub recovery_period: i64,
    pub timeout: i64,
}
Configuration for a Ping monitor.

Fields

check_frequency: i64

How often the monitor should perform a check, in seconds.

confirmation_period: i64

Number of consecutive successful checks required to confirm a state change.

recovery_period: i64

Number of consecutive failed checks required to consider the monitor recovered.

timeout: i64

Maximum time, in seconds, to wait for a ping response before timing out.