Schedule

Struct Schedule 

pub struct Schedule<Item: Schedulable> { /* private fields */ }
A schedule for managing Schedulable items.

The Schedule structure stores items indexed by their unique identifiers and groups item id by their interval. This allows efficient lookup of items by id and retrieval of all id in a given interval.

OperationTime complexity
GetO(1)
Get dueO(m)
InsertO(1)
RemoveO(1)

m - it’s amount of unique intervals.

Implementations

Source

impl<Item: Schedulable> Schedule<Item>

pub fn new() -> Self

Create a new schedule.

pub async fn is_empty(&self) -> bool

Returns true if the Schedule doesn’t contain elements.

pub async fn get(&self, id: Item::Id) -> Option<Arc<Item>>

Get an item by id.

pub async fn get_due(&self, from: i64, to: i64) -> Vec<Arc<Item>>

Get items that are included in the interval from and to.

An element is included in the interval if there is at least one value between from and to that is divisible by the item’s interval without a remainder.

from and to should be > 0 and from should be <= to.

pub async fn insert(&self, item: Item)

Insert an item into schedule.

If an item with this id is already in the schedule, it will be replaced.

pub async fn remove(&self, id: Item::Id)

Remove an item by id from the schedule if it exists.

pub async fn clear(&self)

Clears the schedule, removing all items. Keeps the allocated memory for reuse.