pub struct PingConfig {
pub check_frequency: i64,
pub confirmation_period: i64,
pub recovery_period: i64,
pub timeout: i64,
}Expand description
Configuration for a Ping monitor.
Fields
check_frequency: i64How often the monitor should perform a check, in seconds.
confirmation_period: i64Number of consecutive successful checks required to confirm a state change.
recovery_period: i64Number of consecutive failed checks required to consider the monitor recovered.
timeout: i64Maximum time, in seconds, to wait for a ping response before timing out.