pub struct Schedule<Item: Schedulable> { /* private fields */ }Expand description
A schedule for managing Schedulable items.
The Schedule structure stores items indexed by their unique
identifiers and groups item id by their interval. This allows
efficient lookup of items by id and retrieval of all id in a
given interval.
| Operation | Time complexity |
|---|---|
| Get | O(1) |
| Get due | O(m) |
| Insert | O(1) |
| Remove | O(1) |
m - it’s amount of unique intervals.
Implementations
Sourceimpl<Item: Schedulable> Schedule<Item>
impl<Item: Schedulable> Schedule<Item>
Sourcepub async fn get_due(&self, from: i64, to: i64) -> Vec<Arc<Item>>
pub async fn get_due(&self, from: i64, to: i64) -> Vec<Arc<Item>>
Get items that are included in the interval from and to.
An element is included in the interval if there is at least
one value between from and to that is divisible by
the item’s interval without a remainder.
from and to should be > 0 and from should be <= to.